@@ -138,38 +138,6 @@ And runs the following loop: copies the element at index $i of the return value(
 
 And returns the new array.
 
-=head2 get_ocsp_uri
-
-C<method get_ocsp_uri : string ();>
-
-Returns OCSP URI in the certificate $cert.
-
-If not found, returns undef.
-
-Implementation:
-
-An OCSP URI is got by the following native C codes. C<self> is the pointer value of the instancce.
-
-  STACK_OF(ACCESS_DESCRIPTION)* ads_stack = X509_get_ext_d2i(self, NID_info_access, NULL, NULL);
-  
-  void* obj_ocsp_uri = NULL;
-  
-  if (ads_stack) {
-    for (int32_t i = 0; i < sk_ACCESS_DESCRIPTION_num(ads_stack); i++) {
-      ACCESS_DESCRIPTION *ad = sk_ACCESS_DESCRIPTION_value(ads_stack, i);
-      
-      if (OBJ_obj2nid(ad->method) == NID_ad_OCSP && ad->location->type == GEN_URI) {
-        
-        const char* ocsp_uri = (const char*)ASN1_STRING_get0_data(ad->location->d.uniformResourceIdentifier);
-        int32_t ocsp_uri_length = ASN1_STRING_length(ad->location->d.uniformResourceIdentifier);
-        
-        obj_ocsp_uri = env->new_string(env, stack, ocsp_uri, ocsp_uri_length);
-        
-        break;
-      }
-    }
-  }
-
 =head2 digest
 
 C<method digest : int ($type : L<Net::SSLeay::EVP_MD|SPVM::Net::SSLeay::EVP_MD>, $md : mutable string, $len_ref : int*);>
